# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAclResult',
    'AwaitableGetAclResult',
    'get_acl',
    'get_acl_output',
]

@pulumi.output_type
class GetAclResult:
    """
    A collection of values returned by getAcl.
    """
    def __init__(__self__, acl_entries=None, acl_entry_count=None, acl_id=None, acl_name=None, created_time=None, description=None, id=None, listeners=None, project_name=None, status=None, tags=None, updated_time=None):
        if acl_entries and not isinstance(acl_entries, list):
            raise TypeError("Expected argument 'acl_entries' to be a list")
        pulumi.set(__self__, "acl_entries", acl_entries)
        if acl_entry_count and not isinstance(acl_entry_count, int):
            raise TypeError("Expected argument 'acl_entry_count' to be a int")
        pulumi.set(__self__, "acl_entry_count", acl_entry_count)
        if acl_id and not isinstance(acl_id, str):
            raise TypeError("Expected argument 'acl_id' to be a str")
        pulumi.set(__self__, "acl_id", acl_id)
        if acl_name and not isinstance(acl_name, str):
            raise TypeError("Expected argument 'acl_name' to be a str")
        pulumi.set(__self__, "acl_name", acl_name)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if listeners and not isinstance(listeners, list):
            raise TypeError("Expected argument 'listeners' to be a list")
        pulumi.set(__self__, "listeners", listeners)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="aclEntries")
    def acl_entries(self) -> Sequence['outputs.GetAclAclEntryResult']:
        """
        访问控制策略组中IP条目的详细信息。
        """
        return pulumi.get(self, "acl_entries")

    @property
    @pulumi.getter(name="aclEntryCount")
    def acl_entry_count(self) -> builtins.int:
        """
        访问控制策略组包含的IP条目数量。
        """
        return pulumi.get(self, "acl_entry_count")

    @property
    @pulumi.getter(name="aclId")
    def acl_id(self) -> builtins.str:
        """
        访问控制策略组的ID。
        """
        return pulumi.get(self, "acl_id")

    @property
    @pulumi.getter(name="aclName")
    def acl_name(self) -> builtins.str:
        """
        访问控制策略组的名字。不能以http://或https://开头。必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ～ 128个字符。不填默认为访问控制策略组ID。
        """
        return pulumi.get(self, "acl_name")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        访问控制策略组的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        访问控制策略组的描述。不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。） 。长度限制为1 ～ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def listeners(self) -> Sequence['outputs.GetAclListenerResult']:
        """
        访问控制策略组关联的监听器详细信息。
        """
        return pulumi.get(self, "listeners")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        访问控制策略组所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        访问控制策略组的状态。Creating：创建中。Active：正常可用。Configuring：配置中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetAclTagResult']:
        """
        访问控制策略组绑定的标签。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        访问控制策略组的最近操作时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetAclResult(GetAclResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAclResult(
            acl_entries=self.acl_entries,
            acl_entry_count=self.acl_entry_count,
            acl_id=self.acl_id,
            acl_name=self.acl_name,
            created_time=self.created_time,
            description=self.description,
            id=self.id,
            listeners=self.listeners,
            project_name=self.project_name,
            status=self.status,
            tags=self.tags,
            updated_time=self.updated_time)


def get_acl(id: Optional[builtins.str] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAclResult:
    """
    Data Source schema for Byteplus::ALB::ACL


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:alb/getAcl:getAcl', __args__, opts=opts, typ=GetAclResult).value

    return AwaitableGetAclResult(
        acl_entries=pulumi.get(__ret__, 'acl_entries'),
        acl_entry_count=pulumi.get(__ret__, 'acl_entry_count'),
        acl_id=pulumi.get(__ret__, 'acl_id'),
        acl_name=pulumi.get(__ret__, 'acl_name'),
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        listeners=pulumi.get(__ret__, 'listeners'),
        project_name=pulumi.get(__ret__, 'project_name'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_acl_output(id: Optional[pulumi.Input[builtins.str]] = None,
                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAclResult]:
    """
    Data Source schema for Byteplus::ALB::ACL


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:alb/getAcl:getAcl', __args__, opts=opts, typ=GetAclResult)
    return __ret__.apply(lambda __response__: GetAclResult(
        acl_entries=pulumi.get(__response__, 'acl_entries'),
        acl_entry_count=pulumi.get(__response__, 'acl_entry_count'),
        acl_id=pulumi.get(__response__, 'acl_id'),
        acl_name=pulumi.get(__response__, 'acl_name'),
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        listeners=pulumi.get(__response__, 'listeners'),
        project_name=pulumi.get(__response__, 'project_name'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated_time=pulumi.get(__response__, 'updated_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AclArgs', 'Acl']

@pulumi.input_type
class AclArgs:
    def __init__(__self__, *,
                 acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input['AclAclEntryArgs']]]] = None,
                 acl_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['AclTagArgs']]]] = None):
        """
        The set of arguments for constructing a Acl resource.
        :param pulumi.Input[builtins.str] acl_name: 访问控制策略组的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制为1～128个字符。不填默认为访问控制策略组ID。
        :param pulumi.Input[builtins.str] description: 访问控制策略组的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0～255字符。不填则默认为空字符串。
        :param pulumi.Input[builtins.str] project_name: 访问控制策略组所属项目的名称。不填默认为default。
        """
        if acl_entries is not None:
            pulumi.set(__self__, "acl_entries", acl_entries)
        if acl_name is not None:
            pulumi.set(__self__, "acl_name", acl_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="aclEntries")
    def acl_entries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AclAclEntryArgs']]]]:
        return pulumi.get(self, "acl_entries")

    @acl_entries.setter
    def acl_entries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AclAclEntryArgs']]]]):
        pulumi.set(self, "acl_entries", value)

    @property
    @pulumi.getter(name="aclName")
    def acl_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问控制策略组的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制为1～128个字符。不填默认为访问控制策略组ID。
        """
        return pulumi.get(self, "acl_name")

    @acl_name.setter
    def acl_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "acl_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问控制策略组的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0～255字符。不填则默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问控制策略组所属项目的名称。不填默认为default。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AclTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AclTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _AclState:
    def __init__(__self__, *,
                 acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input['AclAclEntryArgs']]]] = None,
                 acl_entry_count: Optional[pulumi.Input[builtins.int]] = None,
                 acl_id: Optional[pulumi.Input[builtins.str]] = None,
                 acl_name: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 listeners: Optional[pulumi.Input[Sequence[pulumi.Input['AclListenerArgs']]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 service_managed: Optional[pulumi.Input[builtins.bool]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['AclTagArgs']]]] = None,
                 update_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Acl resources.
        :param pulumi.Input[builtins.int] acl_entry_count: 访问控制策略组包含的IP条目数量。
        :param pulumi.Input[builtins.str] acl_id: 访问控制策略组的ID。
        :param pulumi.Input[builtins.str] acl_name: 访问控制策略组的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制为1～128个字符。不填默认为访问控制策略组ID。
        :param pulumi.Input[builtins.str] create_time: 访问控制策略组的创建时间。
        :param pulumi.Input[builtins.str] description: 访问控制策略组的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0～255字符。不填则默认为空字符串。
        :param pulumi.Input[builtins.str] project_name: 访问控制策略组所属项目的名称。不填默认为default。
        :param pulumi.Input[builtins.bool] service_managed: 是否为托管资源。true：是。false：否。
        :param pulumi.Input[builtins.str] status: 访问控制策略组的状态。Creating：创建中。Active：正常可用。Configuring：配置中。Deleting：删除中。
        :param pulumi.Input[builtins.str] update_time: 访问控制策略组的最近操作时间。
        """
        if acl_entries is not None:
            pulumi.set(__self__, "acl_entries", acl_entries)
        if acl_entry_count is not None:
            pulumi.set(__self__, "acl_entry_count", acl_entry_count)
        if acl_id is not None:
            pulumi.set(__self__, "acl_id", acl_id)
        if acl_name is not None:
            pulumi.set(__self__, "acl_name", acl_name)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if listeners is not None:
            pulumi.set(__self__, "listeners", listeners)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if service_managed is not None:
            pulumi.set(__self__, "service_managed", service_managed)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="aclEntries")
    def acl_entries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AclAclEntryArgs']]]]:
        return pulumi.get(self, "acl_entries")

    @acl_entries.setter
    def acl_entries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AclAclEntryArgs']]]]):
        pulumi.set(self, "acl_entries", value)

    @property
    @pulumi.getter(name="aclEntryCount")
    def acl_entry_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        访问控制策略组包含的IP条目数量。
        """
        return pulumi.get(self, "acl_entry_count")

    @acl_entry_count.setter
    def acl_entry_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "acl_entry_count", value)

    @property
    @pulumi.getter(name="aclId")
    def acl_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问控制策略组的ID。
        """
        return pulumi.get(self, "acl_id")

    @acl_id.setter
    def acl_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "acl_id", value)

    @property
    @pulumi.getter(name="aclName")
    def acl_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问控制策略组的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制为1～128个字符。不填默认为访问控制策略组ID。
        """
        return pulumi.get(self, "acl_name")

    @acl_name.setter
    def acl_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "acl_name", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问控制策略组的创建时间。
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问控制策略组的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0～255字符。不填则默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def listeners(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AclListenerArgs']]]]:
        return pulumi.get(self, "listeners")

    @listeners.setter
    def listeners(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AclListenerArgs']]]]):
        pulumi.set(self, "listeners", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问控制策略组所属项目的名称。不填默认为default。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="serviceManaged")
    def service_managed(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否为托管资源。true：是。false：否。
        """
        return pulumi.get(self, "service_managed")

    @service_managed.setter
    def service_managed(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "service_managed", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问控制策略组的状态。Creating：创建中。Active：正常可用。Configuring：配置中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AclTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AclTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问控制策略组的最近操作时间。
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_time", value)


@pulumi.type_token("bytepluscc:clb/acl:Acl")
class Acl(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AclAclEntryArgs', 'AclAclEntryArgsDict']]]]] = None,
                 acl_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AclTagArgs', 'AclTagArgsDict']]]]] = None,
                 __props__=None):
        """
        CLB提供监听级别的访问控制，如果您希望仅允许某些IP、或仅拒绝某些IP通过监听端口访问CLB实例，可以对该监听器设置访问控制策略。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        acl_demo = bytepluscc.clb.Acl("AclDemo",
            acl_name="AclDemo",
            description="AclDemo Example",
            project_name="default",
            acl_entries=[
                {
                    "description": "AclDemo description",
                    "entry": "1.1.2.2/32",
                },
                {
                    "description": "AclDemo description",
                    "entry": "2.2.2.2/32",
                },
            ],
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:clb/acl:Acl example "acl_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] acl_name: 访问控制策略组的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制为1～128个字符。不填默认为访问控制策略组ID。
        :param pulumi.Input[builtins.str] description: 访问控制策略组的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0～255字符。不填则默认为空字符串。
        :param pulumi.Input[builtins.str] project_name: 访问控制策略组所属项目的名称。不填默认为default。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AclArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        CLB提供监听级别的访问控制，如果您希望仅允许某些IP、或仅拒绝某些IP通过监听端口访问CLB实例，可以对该监听器设置访问控制策略。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        acl_demo = bytepluscc.clb.Acl("AclDemo",
            acl_name="AclDemo",
            description="AclDemo Example",
            project_name="default",
            acl_entries=[
                {
                    "description": "AclDemo description",
                    "entry": "1.1.2.2/32",
                },
                {
                    "description": "AclDemo description",
                    "entry": "2.2.2.2/32",
                },
            ],
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:clb/acl:Acl example "acl_id"
        ```

        :param str resource_name: The name of the resource.
        :param AclArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AclArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AclAclEntryArgs', 'AclAclEntryArgsDict']]]]] = None,
                 acl_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AclTagArgs', 'AclTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AclArgs.__new__(AclArgs)

            __props__.__dict__["acl_entries"] = acl_entries
            __props__.__dict__["acl_name"] = acl_name
            __props__.__dict__["description"] = description
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["acl_entry_count"] = None
            __props__.__dict__["acl_id"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["listeners"] = None
            __props__.__dict__["service_managed"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["update_time"] = None
        super(Acl, __self__).__init__(
            'bytepluscc:clb/acl:Acl',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AclAclEntryArgs', 'AclAclEntryArgsDict']]]]] = None,
            acl_entry_count: Optional[pulumi.Input[builtins.int]] = None,
            acl_id: Optional[pulumi.Input[builtins.str]] = None,
            acl_name: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            listeners: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AclListenerArgs', 'AclListenerArgsDict']]]]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            service_managed: Optional[pulumi.Input[builtins.bool]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AclTagArgs', 'AclTagArgsDict']]]]] = None,
            update_time: Optional[pulumi.Input[builtins.str]] = None) -> 'Acl':
        """
        Get an existing Acl resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] acl_entry_count: 访问控制策略组包含的IP条目数量。
        :param pulumi.Input[builtins.str] acl_id: 访问控制策略组的ID。
        :param pulumi.Input[builtins.str] acl_name: 访问控制策略组的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制为1～128个字符。不填默认为访问控制策略组ID。
        :param pulumi.Input[builtins.str] create_time: 访问控制策略组的创建时间。
        :param pulumi.Input[builtins.str] description: 访问控制策略组的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0～255字符。不填则默认为空字符串。
        :param pulumi.Input[builtins.str] project_name: 访问控制策略组所属项目的名称。不填默认为default。
        :param pulumi.Input[builtins.bool] service_managed: 是否为托管资源。true：是。false：否。
        :param pulumi.Input[builtins.str] status: 访问控制策略组的状态。Creating：创建中。Active：正常可用。Configuring：配置中。Deleting：删除中。
        :param pulumi.Input[builtins.str] update_time: 访问控制策略组的最近操作时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AclState.__new__(_AclState)

        __props__.__dict__["acl_entries"] = acl_entries
        __props__.__dict__["acl_entry_count"] = acl_entry_count
        __props__.__dict__["acl_id"] = acl_id
        __props__.__dict__["acl_name"] = acl_name
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["listeners"] = listeners
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["service_managed"] = service_managed
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["update_time"] = update_time
        return Acl(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="aclEntries")
    def acl_entries(self) -> pulumi.Output[Sequence['outputs.AclAclEntry']]:
        return pulumi.get(self, "acl_entries")

    @property
    @pulumi.getter(name="aclEntryCount")
    def acl_entry_count(self) -> pulumi.Output[builtins.int]:
        """
        访问控制策略组包含的IP条目数量。
        """
        return pulumi.get(self, "acl_entry_count")

    @property
    @pulumi.getter(name="aclId")
    def acl_id(self) -> pulumi.Output[builtins.str]:
        """
        访问控制策略组的ID。
        """
        return pulumi.get(self, "acl_id")

    @property
    @pulumi.getter(name="aclName")
    def acl_name(self) -> pulumi.Output[builtins.str]:
        """
        访问控制策略组的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。长度限制为1～128个字符。不填默认为访问控制策略组ID。
        """
        return pulumi.get(self, "acl_name")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        访问控制策略组的创建时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        访问控制策略组的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0～255字符。不填则默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def listeners(self) -> pulumi.Output[Sequence['outputs.AclListener']]:
        return pulumi.get(self, "listeners")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        访问控制策略组所属项目的名称。不填默认为default。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="serviceManaged")
    def service_managed(self) -> pulumi.Output[builtins.bool]:
        """
        是否为托管资源。true：是。false：否。
        """
        return pulumi.get(self, "service_managed")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        访问控制策略组的状态。Creating：创建中。Active：正常可用。Configuring：配置中。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.AclTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[builtins.str]:
        """
        访问控制策略组的最近操作时间。
        """
        return pulumi.get(self, "update_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TransitRouterRouteTableArgs', 'TransitRouterRouteTable']

@pulumi.input_type
class TransitRouterRouteTableArgs:
    def __init__(__self__, *,
                 transit_router_id: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterRouteTableTagArgs']]]] = None,
                 transit_router_route_table_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a TransitRouterRouteTable resource.
        :param pulumi.Input[builtins.str] transit_router_id: 中转路由器实例的ID
        :param pulumi.Input[builtins.str] description: TR路由表的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.str] transit_router_route_table_name: TR路由表的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为TR路由表的ID
        """
        pulumi.set(__self__, "transit_router_id", transit_router_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transit_router_route_table_name is not None:
            pulumi.set(__self__, "transit_router_route_table_name", transit_router_route_table_name)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> pulumi.Input[builtins.str]:
        """
        中转路由器实例的ID
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "transit_router_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterRouteTableTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterRouteTableTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transitRouterRouteTableName")
    def transit_router_route_table_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为TR路由表的ID
        """
        return pulumi.get(self, "transit_router_route_table_name")

    @transit_router_route_table_name.setter
    def transit_router_route_table_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_table_name", value)


@pulumi.input_type
class _TransitRouterRouteTableState:
    def __init__(__self__, *,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 in_route_policy_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 out_route_policy_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterRouteTableTagArgs']]]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_type: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering TransitRouterRouteTable resources.
        :param pulumi.Input[builtins.str] created_time: TR路由表的创建时间
        :param pulumi.Input[builtins.str] description: TR路由表的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.str] in_route_policy_table_id: TR路由表关联的收方向路由策略的ID
        :param pulumi.Input[builtins.str] out_route_policy_table_id: TR路由表关联的发方向路由策略的ID
        :param pulumi.Input[builtins.str] status: TR路由表的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用
        :param pulumi.Input[builtins.str] transit_router_id: 中转路由器实例的ID
        :param pulumi.Input[builtins.str] transit_router_route_table_id: TR路由表的ID
        :param pulumi.Input[builtins.str] transit_router_route_table_name: TR路由表的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为TR路由表的ID
        :param pulumi.Input[builtins.str] transit_router_route_table_type: TR路由表的类型。System：系统路由表。Custom：自定义路由表。
        :param pulumi.Input[builtins.str] updated_time: TR路由表的最近操作时间
        """
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if in_route_policy_table_id is not None:
            pulumi.set(__self__, "in_route_policy_table_id", in_route_policy_table_id)
        if out_route_policy_table_id is not None:
            pulumi.set(__self__, "out_route_policy_table_id", out_route_policy_table_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transit_router_id is not None:
            pulumi.set(__self__, "transit_router_id", transit_router_id)
        if transit_router_route_table_id is not None:
            pulumi.set(__self__, "transit_router_route_table_id", transit_router_route_table_id)
        if transit_router_route_table_name is not None:
            pulumi.set(__self__, "transit_router_route_table_name", transit_router_route_table_name)
        if transit_router_route_table_type is not None:
            pulumi.set(__self__, "transit_router_route_table_type", transit_router_route_table_type)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的创建时间
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="inRoutePolicyTableId")
    def in_route_policy_table_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表关联的收方向路由策略的ID
        """
        return pulumi.get(self, "in_route_policy_table_id")

    @in_route_policy_table_id.setter
    def in_route_policy_table_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "in_route_policy_table_id", value)

    @property
    @pulumi.getter(name="outRoutePolicyTableId")
    def out_route_policy_table_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表关联的发方向路由策略的ID
        """
        return pulumi.get(self, "out_route_policy_table_id")

    @out_route_policy_table_id.setter
    def out_route_policy_table_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "out_route_policy_table_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterRouteTableTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterRouteTableTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转路由器实例的ID
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_id", value)

    @property
    @pulumi.getter(name="transitRouterRouteTableId")
    def transit_router_route_table_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的ID
        """
        return pulumi.get(self, "transit_router_route_table_id")

    @transit_router_route_table_id.setter
    def transit_router_route_table_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_table_id", value)

    @property
    @pulumi.getter(name="transitRouterRouteTableName")
    def transit_router_route_table_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为TR路由表的ID
        """
        return pulumi.get(self, "transit_router_route_table_name")

    @transit_router_route_table_name.setter
    def transit_router_route_table_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_table_name", value)

    @property
    @pulumi.getter(name="transitRouterRouteTableType")
    def transit_router_route_table_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的类型。System：系统路由表。Custom：自定义路由表。
        """
        return pulumi.get(self, "transit_router_route_table_type")

    @transit_router_route_table_type.setter
    def transit_router_route_table_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_table_type", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TR路由表的最近操作时间
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:transitrouter/transitRouterRouteTable:TransitRouterRouteTable")
class TransitRouterRouteTable(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TransitRouterRouteTableTagArgs', 'TransitRouterRouteTableTagArgsDict']]]]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        中转路由器转发流量的依据，具有关联转发、静态路由、路由学习、路由同步等能力。每个TR实例下可以创建多个TR路由表，分别用于转发具有不同访问需求的网络实例的流量。多条网络实例连接可以关联同一个TR路由表。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        transit_router_transit_router_route_table_demo = bytepluscc.transitrouter.TransitRouterRouteTable("TransitRouterTransitRouterRouteTableDemo",
            transit_router_id="tr-mj7mc0paq******",
            description="TransitRouterTransitRouterRouteTableDemo-Description",
            transit_router_route_table_name="TransitRouterTransitRouterRouteTableDemo",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:transitrouter/transitRouterRouteTable:TransitRouterRouteTable example "transit_router_id|transit_router_route_table_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: TR路由表的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.str] transit_router_id: 中转路由器实例的ID
        :param pulumi.Input[builtins.str] transit_router_route_table_name: TR路由表的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为TR路由表的ID
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TransitRouterRouteTableArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        中转路由器转发流量的依据，具有关联转发、静态路由、路由学习、路由同步等能力。每个TR实例下可以创建多个TR路由表，分别用于转发具有不同访问需求的网络实例的流量。多条网络实例连接可以关联同一个TR路由表。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        transit_router_transit_router_route_table_demo = bytepluscc.transitrouter.TransitRouterRouteTable("TransitRouterTransitRouterRouteTableDemo",
            transit_router_id="tr-mj7mc0paq******",
            description="TransitRouterTransitRouterRouteTableDemo-Description",
            transit_router_route_table_name="TransitRouterTransitRouterRouteTableDemo",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:transitrouter/transitRouterRouteTable:TransitRouterRouteTable example "transit_router_id|transit_router_route_table_id"
        ```

        :param str resource_name: The name of the resource.
        :param TransitRouterRouteTableArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TransitRouterRouteTableArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TransitRouterRouteTableTagArgs', 'TransitRouterRouteTableTagArgsDict']]]]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TransitRouterRouteTableArgs.__new__(TransitRouterRouteTableArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["tags"] = tags
            if transit_router_id is None and not opts.urn:
                raise TypeError("Missing required property 'transit_router_id'")
            __props__.__dict__["transit_router_id"] = transit_router_id
            __props__.__dict__["transit_router_route_table_name"] = transit_router_route_table_name
            __props__.__dict__["created_time"] = None
            __props__.__dict__["in_route_policy_table_id"] = None
            __props__.__dict__["out_route_policy_table_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["transit_router_route_table_id"] = None
            __props__.__dict__["transit_router_route_table_type"] = None
            __props__.__dict__["updated_time"] = None
        super(TransitRouterRouteTable, __self__).__init__(
            'bytepluscc:transitrouter/transitRouterRouteTable:TransitRouterRouteTable',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            in_route_policy_table_id: Optional[pulumi.Input[builtins.str]] = None,
            out_route_policy_table_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TransitRouterRouteTableTagArgs', 'TransitRouterRouteTableTagArgsDict']]]]] = None,
            transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_route_table_id: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_route_table_name: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_route_table_type: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'TransitRouterRouteTable':
        """
        Get an existing TransitRouterRouteTable resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_time: TR路由表的创建时间
        :param pulumi.Input[builtins.str] description: TR路由表的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.str] in_route_policy_table_id: TR路由表关联的收方向路由策略的ID
        :param pulumi.Input[builtins.str] out_route_policy_table_id: TR路由表关联的发方向路由策略的ID
        :param pulumi.Input[builtins.str] status: TR路由表的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用
        :param pulumi.Input[builtins.str] transit_router_id: 中转路由器实例的ID
        :param pulumi.Input[builtins.str] transit_router_route_table_id: TR路由表的ID
        :param pulumi.Input[builtins.str] transit_router_route_table_name: TR路由表的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为TR路由表的ID
        :param pulumi.Input[builtins.str] transit_router_route_table_type: TR路由表的类型。System：系统路由表。Custom：自定义路由表。
        :param pulumi.Input[builtins.str] updated_time: TR路由表的最近操作时间
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TransitRouterRouteTableState.__new__(_TransitRouterRouteTableState)

        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["in_route_policy_table_id"] = in_route_policy_table_id
        __props__.__dict__["out_route_policy_table_id"] = out_route_policy_table_id
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["transit_router_id"] = transit_router_id
        __props__.__dict__["transit_router_route_table_id"] = transit_router_route_table_id
        __props__.__dict__["transit_router_route_table_name"] = transit_router_route_table_name
        __props__.__dict__["transit_router_route_table_type"] = transit_router_route_table_type
        __props__.__dict__["updated_time"] = updated_time
        return TransitRouterRouteTable(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表的创建时间
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="inRoutePolicyTableId")
    def in_route_policy_table_id(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表关联的收方向路由策略的ID
        """
        return pulumi.get(self, "in_route_policy_table_id")

    @property
    @pulumi.getter(name="outRoutePolicyTableId")
    def out_route_policy_table_id(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表关联的发方向路由策略的ID
        """
        return pulumi.get(self, "out_route_policy_table_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.TransitRouterRouteTableTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> pulumi.Output[builtins.str]:
        """
        中转路由器实例的ID
        """
        return pulumi.get(self, "transit_router_id")

    @property
    @pulumi.getter(name="transitRouterRouteTableId")
    def transit_router_route_table_id(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表的ID
        """
        return pulumi.get(self, "transit_router_route_table_id")

    @property
    @pulumi.getter(name="transitRouterRouteTableName")
    def transit_router_route_table_name(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为TR路由表的ID
        """
        return pulumi.get(self, "transit_router_route_table_name")

    @property
    @pulumi.getter(name="transitRouterRouteTableType")
    def transit_router_route_table_type(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表的类型。System：系统路由表。Custom：自定义路由表。
        """
        return pulumi.get(self, "transit_router_route_table_type")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        TR路由表的最近操作时间
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GroupArgs', 'Group']

@pulumi.input_type
class GroupArgs:
    def __init__(__self__, *,
                 user_group_name: pulumi.Input[builtins.str],
                 attached_policies: Optional[pulumi.Input[Sequence[pulumi.Input['GroupAttachedPolicyArgs']]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input['GroupUserArgs']]]] = None):
        """
        The set of arguments for constructing a Group resource.
        :param pulumi.Input[builtins.str] user_group_name: 用户组名称。长度1~64，支持英文、数字和.-_符号。
        :param pulumi.Input[builtins.str] description: 用户组描述信息。长度不超过128。
        :param pulumi.Input[builtins.str] display_name: 用户组显示名称。长度不超过64。
        """
        pulumi.set(__self__, "user_group_name", user_group_name)
        if attached_policies is not None:
            pulumi.set(__self__, "attached_policies", attached_policies)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter(name="userGroupName")
    def user_group_name(self) -> pulumi.Input[builtins.str]:
        """
        用户组名称。长度1~64，支持英文、数字和.-_符号。
        """
        return pulumi.get(self, "user_group_name")

    @user_group_name.setter
    def user_group_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "user_group_name", value)

    @property
    @pulumi.getter(name="attachedPolicies")
    def attached_policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupAttachedPolicyArgs']]]]:
        return pulumi.get(self, "attached_policies")

    @attached_policies.setter
    def attached_policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupAttachedPolicyArgs']]]]):
        pulumi.set(self, "attached_policies", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户组描述信息。长度不超过128。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户组显示名称。长度不超过64。
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupUserArgs']]]]:
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupUserArgs']]]]):
        pulumi.set(self, "users", value)


@pulumi.input_type
class _GroupState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.int]] = None,
                 attached_policies: Optional[pulumi.Input[Sequence[pulumi.Input['GroupAttachedPolicyArgs']]]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 user_group_id: Optional[pulumi.Input[builtins.int]] = None,
                 user_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input['GroupUserArgs']]]] = None):
        """
        Input properties used for looking up and filtering Group resources.
        :param pulumi.Input[builtins.int] account_id: 用户组所属主账号的ID。
        :param pulumi.Input[builtins.str] created_time: 用户组的创建时间。
        :param pulumi.Input[builtins.str] description: 用户组描述信息。长度不超过128。
        :param pulumi.Input[builtins.str] display_name: 用户组显示名称。长度不超过64。
        :param pulumi.Input[builtins.str] updated_time: 用户组的更新时间。
        :param pulumi.Input[builtins.int] user_group_id: 用户组ID。
        :param pulumi.Input[builtins.str] user_group_name: 用户组名称。长度1~64，支持英文、数字和.-_符号。
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if attached_policies is not None:
            pulumi.set(__self__, "attached_policies", attached_policies)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if user_group_id is not None:
            pulumi.set(__self__, "user_group_id", user_group_id)
        if user_group_name is not None:
            pulumi.set(__self__, "user_group_name", user_group_name)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        用户组所属主账号的ID。
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="attachedPolicies")
    def attached_policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupAttachedPolicyArgs']]]]:
        return pulumi.get(self, "attached_policies")

    @attached_policies.setter
    def attached_policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupAttachedPolicyArgs']]]]):
        pulumi.set(self, "attached_policies", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户组的创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户组描述信息。长度不超过128。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户组显示名称。长度不超过64。
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户组的更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="userGroupId")
    def user_group_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        用户组ID。
        """
        return pulumi.get(self, "user_group_id")

    @user_group_id.setter
    def user_group_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "user_group_id", value)

    @property
    @pulumi.getter(name="userGroupName")
    def user_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户组名称。长度1~64，支持英文、数字和.-_符号。
        """
        return pulumi.get(self, "user_group_name")

    @user_group_name.setter
    def user_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_group_name", value)

    @property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupUserArgs']]]]:
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupUserArgs']]]]):
        pulumi.set(self, "users", value)


@pulumi.type_token("bytepluscc:iam/group:Group")
class Group(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 attached_policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupAttachedPolicyArgs', 'GroupAttachedPolicyArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 user_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupUserArgs', 'GroupUserArgsDict']]]]] = None,
                 __props__=None):
        """
        用户组是用户的集合。当用户组被关联上策略后，同一用户组里的所有用户会拥有对应的策略权限，同一个用户可存在于多个用户组中，可同时拥有多个用户组的权限。

        ## Import

        ```sh
        $ pulumi import bytepluscc:iam/group:Group example "user_group_name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 用户组描述信息。长度不超过128。
        :param pulumi.Input[builtins.str] display_name: 用户组显示名称。长度不超过64。
        :param pulumi.Input[builtins.str] user_group_name: 用户组名称。长度1~64，支持英文、数字和.-_符号。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        用户组是用户的集合。当用户组被关联上策略后，同一用户组里的所有用户会拥有对应的策略权限，同一个用户可存在于多个用户组中，可同时拥有多个用户组的权限。

        ## Import

        ```sh
        $ pulumi import bytepluscc:iam/group:Group example "user_group_name"
        ```

        :param str resource_name: The name of the resource.
        :param GroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 attached_policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupAttachedPolicyArgs', 'GroupAttachedPolicyArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 user_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupUserArgs', 'GroupUserArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupArgs.__new__(GroupArgs)

            __props__.__dict__["attached_policies"] = attached_policies
            __props__.__dict__["description"] = description
            __props__.__dict__["display_name"] = display_name
            if user_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'user_group_name'")
            __props__.__dict__["user_group_name"] = user_group_name
            __props__.__dict__["users"] = users
            __props__.__dict__["account_id"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["updated_time"] = None
            __props__.__dict__["user_group_id"] = None
        super(Group, __self__).__init__(
            'bytepluscc:iam/group:Group',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.int]] = None,
            attached_policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupAttachedPolicyArgs', 'GroupAttachedPolicyArgsDict']]]]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            user_group_id: Optional[pulumi.Input[builtins.int]] = None,
            user_group_name: Optional[pulumi.Input[builtins.str]] = None,
            users: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupUserArgs', 'GroupUserArgsDict']]]]] = None) -> 'Group':
        """
        Get an existing Group resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] account_id: 用户组所属主账号的ID。
        :param pulumi.Input[builtins.str] created_time: 用户组的创建时间。
        :param pulumi.Input[builtins.str] description: 用户组描述信息。长度不超过128。
        :param pulumi.Input[builtins.str] display_name: 用户组显示名称。长度不超过64。
        :param pulumi.Input[builtins.str] updated_time: 用户组的更新时间。
        :param pulumi.Input[builtins.int] user_group_id: 用户组ID。
        :param pulumi.Input[builtins.str] user_group_name: 用户组名称。长度1~64，支持英文、数字和.-_符号。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupState.__new__(_GroupState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["attached_policies"] = attached_policies
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["user_group_id"] = user_group_id
        __props__.__dict__["user_group_name"] = user_group_name
        __props__.__dict__["users"] = users
        return Group(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.int]:
        """
        用户组所属主账号的ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="attachedPolicies")
    def attached_policies(self) -> pulumi.Output[Sequence['outputs.GroupAttachedPolicy']]:
        return pulumi.get(self, "attached_policies")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        用户组的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        用户组描述信息。长度不超过128。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[builtins.str]:
        """
        用户组显示名称。长度不超过64。
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        用户组的更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="userGroupId")
    def user_group_id(self) -> pulumi.Output[builtins.int]:
        """
        用户组ID。
        """
        return pulumi.get(self, "user_group_id")

    @property
    @pulumi.getter(name="userGroupName")
    def user_group_name(self) -> pulumi.Output[builtins.str]:
        """
        用户组名称。长度1~64，支持英文、数字和.-_符号。
        """
        return pulumi.get(self, "user_group_name")

    @property
    @pulumi.getter
    def users(self) -> pulumi.Output[Sequence['outputs.GroupUser']]:
        return pulumi.get(self, "users")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetRegistryResult',
    'AwaitableGetRegistryResult',
    'get_registry',
    'get_registry_output',
]

@pulumi.output_type
class GetRegistryResult:
    """
    A collection of values returned by getRegistry.
    """
    def __init__(__self__, charge_type=None, created_time=None, expire_time=None, id=None, name=None, project=None, proxy_cache=None, proxy_cache_enabled=None, renew_type=None, status=None, tags=None, type=None):
        if charge_type and not isinstance(charge_type, str):
            raise TypeError("Expected argument 'charge_type' to be a str")
        pulumi.set(__self__, "charge_type", charge_type)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if expire_time and not isinstance(expire_time, str):
            raise TypeError("Expected argument 'expire_time' to be a str")
        pulumi.set(__self__, "expire_time", expire_time)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if proxy_cache and not isinstance(proxy_cache, dict):
            raise TypeError("Expected argument 'proxy_cache' to be a dict")
        pulumi.set(__self__, "proxy_cache", proxy_cache)
        if proxy_cache_enabled and not isinstance(proxy_cache_enabled, bool):
            raise TypeError("Expected argument 'proxy_cache_enabled' to be a bool")
        pulumi.set(__self__, "proxy_cache_enabled", proxy_cache_enabled)
        if renew_type and not isinstance(renew_type, str):
            raise TypeError("Expected argument 'renew_type' to be a str")
        pulumi.set(__self__, "renew_type", renew_type)
        if status and not isinstance(status, dict):
            raise TypeError("Expected argument 'status' to be a dict")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> builtins.str:
        """
        镜像仓库实例的付费类型，目前仅支持 PostCharge按量付费模式。
        """
        return pulumi.get(self, "charge_type")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建镜像仓库实例的时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> builtins.str:
        """
        仅计费类型为HybridCharge有值，实例到期时间
        """
        return pulumi.get(self, "expire_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        标准版实例名称，同一个地域下，名称必须唯一。支持小写英文字母、数字、短划线（-）且数字不能在首位，短划线（-）不能在首位或末位，长度限制为 3～30 个字符。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> builtins.str:
        """
        填写实例需要关联的项目。一个实例仅支持关联一个项目
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="proxyCache")
    def proxy_cache(self) -> 'outputs.GetRegistryProxyCacheResult':
        """
        ProxyCache配置，设置为ProxyCache时必填
        """
        return pulumi.get(self, "proxy_cache")

    @property
    @pulumi.getter(name="proxyCacheEnabled")
    def proxy_cache_enabled(self) -> builtins.bool:
        """
        是否设置为ProxyCache实例
        """
        return pulumi.get(self, "proxy_cache_enabled")

    @property
    @pulumi.getter(name="renewType")
    def renew_type(self) -> builtins.str:
        """
        仅计费类型为HybridCharge有值，实例自动续费类型
        """
        return pulumi.get(self, "renew_type")

    @property
    @pulumi.getter
    def status(self) -> 'outputs.GetRegistryStatusResult':
        """
        镜像仓库实例状态，由 Phase 和 Conditions 组成。合法的 Phase 和 Conditions 组合如下所示：{Creating, [Progressing]}：创建中,{Running, [Ok]}：运行中,{Running, [Degraded]}：运行中,{Stopped, [Balance]}：欠费关停,{Stopped, [Released]}：待回收,{Stopped, [Released, Balance]}：欠费关停,{Starting, [Progressing]}：启动中,{Deleting, [Progressing]}：销毁中,{Failed, [Unknown]}：异常
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetRegistryTagResult']:
        """
        实例的标签
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        不填写默认创建标准版实例。Enterprise：标准版，Micro：小微版
        """
        return pulumi.get(self, "type")


class AwaitableGetRegistryResult(GetRegistryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRegistryResult(
            charge_type=self.charge_type,
            created_time=self.created_time,
            expire_time=self.expire_time,
            id=self.id,
            name=self.name,
            project=self.project,
            proxy_cache=self.proxy_cache,
            proxy_cache_enabled=self.proxy_cache_enabled,
            renew_type=self.renew_type,
            status=self.status,
            tags=self.tags,
            type=self.type)


def get_registry(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRegistryResult:
    """
    Data Source schema for Byteplus::CR::Registry


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:cr/getRegistry:getRegistry', __args__, opts=opts, typ=GetRegistryResult).value

    return AwaitableGetRegistryResult(
        charge_type=pulumi.get(__ret__, 'charge_type'),
        created_time=pulumi.get(__ret__, 'created_time'),
        expire_time=pulumi.get(__ret__, 'expire_time'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        project=pulumi.get(__ret__, 'project'),
        proxy_cache=pulumi.get(__ret__, 'proxy_cache'),
        proxy_cache_enabled=pulumi.get(__ret__, 'proxy_cache_enabled'),
        renew_type=pulumi.get(__ret__, 'renew_type'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        type=pulumi.get(__ret__, 'type'))
def get_registry_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRegistryResult]:
    """
    Data Source schema for Byteplus::CR::Registry


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:cr/getRegistry:getRegistry', __args__, opts=opts, typ=GetRegistryResult)
    return __ret__.apply(lambda __response__: GetRegistryResult(
        charge_type=pulumi.get(__response__, 'charge_type'),
        created_time=pulumi.get(__response__, 'created_time'),
        expire_time=pulumi.get(__response__, 'expire_time'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        project=pulumi.get(__response__, 'project'),
        proxy_cache=pulumi.get(__response__, 'proxy_cache'),
        proxy_cache_enabled=pulumi.get(__response__, 'proxy_cache_enabled'),
        renew_type=pulumi.get(__response__, 'renew_type'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        type=pulumi.get(__response__, 'type')))
